# swagger-client
Daily and hourly climatological weather data for latitude/longitude points, ZIP/Postal Codes, Designated Market Areas, and OnPoint™ points. The Weather Source Climatology API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate analysis. We offer the highest resolution grid on the market, covering every landmass in the world and up to 200 miles offshore.  An API key is required to authorize requests. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). 

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2.0.0
- Package version: 1.0.0
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen
For more information, please visit [https://developer.weathersourceapis.com/](https://developer.weathersourceapis.com/)

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import swagger_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import swagger_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: ApiKeyAuth
configuration = swagger_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.DmasApi(swagger_client.ApiClient(configuration))
dma_id = 56 # int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
_date = '2013-10-20' # date | An date formatted as a RFC3339 date value.
fields = ['fields_example'] # list[str] | A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
unit_scale = 'IMPERIAL' # str | The unit scale for returned values.<br> (optional) (default to IMPERIAL)

try:
    # A day of weather climatology for a DMA.
    api_response = api_instance.dmas_dma_id_days_date_get(dma_id, _date, fields, unit_scale=unit_scale)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DmasApi->dmas_dma_id_days_date_get: %s\n" % e)

# Configure API key authorization: ApiKeyAuth
configuration = swagger_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.DmasApi(swagger_client.ApiClient(configuration))
dma_id = 56 # int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
date_start = '2013-10-20' # date | An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
date_end = '2013-10-20' # date | An date formatted as a RFC3339 date value that must occur temporally after dateStart.
fields = ['fields_example'] # list[str] | A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
unit_scale = 'IMPERIAL' # str | The unit scale for returned values.<br> (optional) (default to IMPERIAL)

try:
    # A contiguous range of daily weather climatology for a DMA.
    api_response = api_instance.dmas_dma_id_days_date_startdate_end_get(dma_id, date_start, date_end, fields, unit_scale=unit_scale)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DmasApi->dmas_dma_id_days_date_startdate_end_get: %s\n" % e)

# Configure API key authorization: ApiKeyAuth
configuration = swagger_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.DmasApi(swagger_client.ApiClient(configuration))
dma_id = 56 # int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
timestamp = '2013-10-20T19:20:30+01:00' # datetime | A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
fields = ['fields_example'] # list[str] | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
unit_scale = 'IMPERIAL' # str | The unit scale for returned values.<br> (optional) (default to IMPERIAL)

try:
    # An hour of weather climatology for a DMA
    api_response = api_instance.dmas_dma_id_hours_timestamp_get(dma_id, timestamp, fields, unit_scale=unit_scale)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DmasApi->dmas_dma_id_hours_timestamp_get: %s\n" % e)

# Configure API key authorization: ApiKeyAuth
configuration = swagger_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.DmasApi(swagger_client.ApiClient(configuration))
dma_id = 56 # int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
timestamp_start = '2013-10-20T19:20:30+01:00' # datetime | A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
timestamp_end = '2013-10-20T19:20:30+01:00' # datetime | A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
fields = ['fields_example'] # list[str] | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
unit_scale = 'IMPERIAL' # str | The unit scale for returned values.<br> (optional) (default to IMPERIAL)

try:
    # A contiguous range of hourly weather climatology for a DMA.
    api_response = api_instance.dmas_dma_id_hours_timestamp_starttimestamp_end_get(dma_id, timestamp_start, timestamp_end, fields, unit_scale=unit_scale)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DmasApi->dmas_dma_id_hours_timestamp_starttimestamp_end_get: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://climatology.weathersourceapis.com/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DmasApi* | [**dmas_dma_id_days_date_get**](docs/DmasApi.md#dmas_dma_id_days_date_get) | **GET** /dmas/{dmaId}/days/{date} | A day of weather climatology for a DMA.
*DmasApi* | [**dmas_dma_id_days_date_startdate_end_get**](docs/DmasApi.md#dmas_dma_id_days_date_startdate_end_get) | **GET** /dmas/{dmaId}/days/{dateStart},{dateEnd} | A contiguous range of daily weather climatology for a DMA.
*DmasApi* | [**dmas_dma_id_hours_timestamp_get**](docs/DmasApi.md#dmas_dma_id_hours_timestamp_get) | **GET** /dmas/{dmaId}/hours/{timestamp} | An hour of weather climatology for a DMA
*DmasApi* | [**dmas_dma_id_hours_timestamp_starttimestamp_end_get**](docs/DmasApi.md#dmas_dma_id_hours_timestamp_starttimestamp_end_get) | **GET** /dmas/{dmaId}/hours/{timestampStart},{timestampEnd} | A contiguous range of hourly weather climatology for a DMA.
*OnpointsApi* | [**onpoints_onpoint_id_days_date_get**](docs/OnpointsApi.md#onpoints_onpoint_id_days_date_get) | **GET** /onpoints/{onpointId}/days/{date} | A day of weather climatology for an OnPoint™ point.
*OnpointsApi* | [**onpoints_onpoint_id_days_date_startdate_end_get**](docs/OnpointsApi.md#onpoints_onpoint_id_days_date_startdate_end_get) | **GET** /onpoints/{onpointId}/days/{dateStart},{dateEnd} | A contiguous range of daily weather climatology for an OnPoint™ point.
*OnpointsApi* | [**onpoints_onpoint_id_hours_timestamp_get**](docs/OnpointsApi.md#onpoints_onpoint_id_hours_timestamp_get) | **GET** /onpoints/{onpointId}/hours/{timestamp} | An hour of weather climatology for an OnPoint™ point.
*OnpointsApi* | [**onpoints_onpoint_id_hours_timestamp_starttimestamp_end_get**](docs/OnpointsApi.md#onpoints_onpoint_id_hours_timestamp_starttimestamp_end_get) | **GET** /onpoints/{onpointId}/hours/{timestampStart},{timestampEnd} | A contiguous range of hourly weather climatology for an OnPoint™ point.
*PointsApi* | [**points_latitudelongitude_days_date_get**](docs/PointsApi.md#points_latitudelongitude_days_date_get) | **GET** /points/{latitude},{longitude}/days/{date} | A day of weather climatology for a Latitude/Longitude point.
*PointsApi* | [**points_latitudelongitude_days_date_startdate_end_get**](docs/PointsApi.md#points_latitudelongitude_days_date_startdate_end_get) | **GET** /points/{latitude},{longitude}/days/{dateStart},{dateEnd} | A contiguous range of daily weather climatology for a Latitude/Longitude point.
*PointsApi* | [**points_latitudelongitude_hours_timestamp_get**](docs/PointsApi.md#points_latitudelongitude_hours_timestamp_get) | **GET** /points/{latitude},{longitude}/hours/{timestamp} | An hour of weather climatology for a Latitude/Longitude point.
*PointsApi* | [**points_latitudelongitude_hours_timestamp_starttimestamp_end_get**](docs/PointsApi.md#points_latitudelongitude_hours_timestamp_starttimestamp_end_get) | **GET** /points/{latitude},{longitude}/hours/{timestampStart},{timestampEnd} | A contiguous range of hourly weather climatology for a Latitude/Longitude point.
*PostcodesApi* | [**postcodes_postcodecountry_code_days_date_get**](docs/PostcodesApi.md#postcodes_postcodecountry_code_days_date_get) | **GET** /postcodes/{postcode},{countryCode}/days/{date} | A day of weather climatology for a postcode.
*PostcodesApi* | [**postcodes_postcodecountry_code_days_date_startdate_end_get**](docs/PostcodesApi.md#postcodes_postcodecountry_code_days_date_startdate_end_get) | **GET** /postcodes/{postcode},{countryCode}/days/{dateStart},{dateEnd} | A contiguous range of daily weather climatology for a postcode.
*PostcodesApi* | [**postcodes_postcodecountry_code_hours_timestamp_get**](docs/PostcodesApi.md#postcodes_postcodecountry_code_hours_timestamp_get) | **GET** /postcodes/{postcode},{countryCode}/hours/{timestamp} | An hour of weather climatology for a postcode.
*PostcodesApi* | [**postcodes_postcodecountry_code_hours_timestamp_starttimestamp_end_get**](docs/PostcodesApi.md#postcodes_postcodecountry_code_hours_timestamp_starttimestamp_end_get) | **GET** /postcodes/{postcode},{countryCode}/hours/{timestampStart},{timestampEnd} | A contiguous range of hourly weather climatology for a postcode.

## Documentation For Models

 - [BoundingPoints](docs/BoundingPoints.md)
 - [BoundingPointsInner](docs/BoundingPointsInner.md)
 - [CldCvr](docs/CldCvr.md)
 - [CldCvrAvg](docs/CldCvrAvg.md)
 - [CldCvrAvgSd](docs/CldCvrAvgSd.md)
 - [CldCvrMax](docs/CldCvrMax.md)
 - [CldCvrMaxSd](docs/CldCvrMaxSd.md)
 - [CldCvrMin](docs/CldCvrMin.md)
 - [CldCvrMinSd](docs/CldCvrMinSd.md)
 - [CldCvrSd](docs/CldCvrSd.md)
 - [ClimatologyDayArr](docs/ClimatologyDayArr.md)
 - [ClimatologyDayObj](docs/ClimatologyDayObj.md)
 - [ClimatologyDmaDayObj](docs/ClimatologyDmaDayObj.md)
 - [ClimatologyDmaHourObj](docs/ClimatologyDmaHourObj.md)
 - [ClimatologyHourArr](docs/ClimatologyHourArr.md)
 - [ClimatologyHourObj](docs/ClimatologyHourObj.md)
 - [ClimatologyOnpointDayObj](docs/ClimatologyOnpointDayObj.md)
 - [ClimatologyOnpointHourObj](docs/ClimatologyOnpointHourObj.md)
 - [ClimatologyPointDayObj](docs/ClimatologyPointDayObj.md)
 - [ClimatologyPointHourObj](docs/ClimatologyPointHourObj.md)
 - [ClimatologyPostcodeDayObj](docs/ClimatologyPostcodeDayObj.md)
 - [ClimatologyPostcodeHourObj](docs/ClimatologyPostcodeHourObj.md)
 - [CountryCode](docs/CountryCode.md)
 - [CountryName](docs/CountryName.md)
 - [DateEnd](docs/DateEnd.md)
 - [DateRangeObj](docs/DateRangeObj.md)
 - [DateStart](docs/DateStart.md)
 - [DewPt](docs/DewPt.md)
 - [DewPtAvg](docs/DewPtAvg.md)
 - [DewPtAvgSd](docs/DewPtAvgSd.md)
 - [DewPtMax](docs/DewPtMax.md)
 - [DewPtMaxSd](docs/DewPtMaxSd.md)
 - [DewPtMin](docs/DewPtMin.md)
 - [DewPtMinSd](docs/DewPtMinSd.md)
 - [DewPtSd](docs/DewPtSd.md)
 - [Distance](docs/Distance.md)
 - [DistancePop](docs/DistancePop.md)
 - [DmaId](docs/DmaId.md)
 - [DmaName](docs/DmaName.md)
 - [DmaObj](docs/DmaObj.md)
 - [ErrorObj](docs/ErrorObj.md)
 - [FeelsLike](docs/FeelsLike.md)
 - [FeelsLikeAvg](docs/FeelsLikeAvg.md)
 - [FeelsLikeAvgSd](docs/FeelsLikeAvgSd.md)
 - [FeelsLikeMax](docs/FeelsLikeMax.md)
 - [FeelsLikeMaxSd](docs/FeelsLikeMaxSd.md)
 - [FeelsLikeMin](docs/FeelsLikeMin.md)
 - [FeelsLikeMinSd](docs/FeelsLikeMinSd.md)
 - [FeelsLikeSd](docs/FeelsLikeSd.md)
 - [FieldListDayObj](docs/FieldListDayObj.md)
 - [FieldListHourObj](docs/FieldListHourObj.md)
 - [Fields](docs/Fields.md)
 - [Grid](docs/Grid.md)
 - [Latitude](docs/Latitude.md)
 - [Longitude](docs/Longitude.md)
 - [ModelDate](docs/ModelDate.md)
 - [MslPres](docs/MslPres.md)
 - [MslPresAvg](docs/MslPresAvg.md)
 - [MslPresAvgSd](docs/MslPresAvgSd.md)
 - [MslPresMax](docs/MslPresMax.md)
 - [MslPresMaxSd](docs/MslPresMaxSd.md)
 - [MslPresMin](docs/MslPresMin.md)
 - [MslPresMinSd](docs/MslPresMinSd.md)
 - [MslPresSd](docs/MslPresSd.md)
 - [OnpointId](docs/OnpointId.md)
 - [OnpointObj](docs/OnpointObj.md)
 - [PointObj](docs/PointObj.md)
 - [Population](docs/Population.md)
 - [Postcode](docs/Postcode.md)
 - [PostcodeObj](docs/PostcodeObj.md)
 - [Precip](docs/Precip.md)
 - [PrecipFreq](docs/PrecipFreq.md)
 - [PrecipFreq0](docs/PrecipFreq0.md)
 - [PrecipFreq001To009](docs/PrecipFreq001To009.md)
 - [PrecipFreq010To024](docs/PrecipFreq010To024.md)
 - [PrecipFreq025To049](docs/PrecipFreq025To049.md)
 - [PrecipFreq050To099](docs/PrecipFreq050To099.md)
 - [PrecipFreq100To249](docs/PrecipFreq100To249.md)
 - [PrecipFreq250To499](docs/PrecipFreq250To499.md)
 - [PrecipFreq500Plus](docs/PrecipFreq500Plus.md)
 - [PrecipSd](docs/PrecipSd.md)
 - [RadSolar](docs/RadSolar.md)
 - [RadSolarAvg](docs/RadSolarAvg.md)
 - [RadSolarAvgSd](docs/RadSolarAvgSd.md)
 - [RadSolarMax](docs/RadSolarMax.md)
 - [RadSolarMaxSd](docs/RadSolarMaxSd.md)
 - [RadSolarMin](docs/RadSolarMin.md)
 - [RadSolarMinSd](docs/RadSolarMinSd.md)
 - [RadSolarSd](docs/RadSolarSd.md)
 - [RadSolarTot](docs/RadSolarTot.md)
 - [RadSolarTotSd](docs/RadSolarTotSd.md)
 - [RelHum](docs/RelHum.md)
 - [RelHumAvg](docs/RelHumAvg.md)
 - [RelHumAvgSd](docs/RelHumAvgSd.md)
 - [RelHumMax](docs/RelHumMax.md)
 - [RelHumMaxSd](docs/RelHumMaxSd.md)
 - [RelHumMin](docs/RelHumMin.md)
 - [RelHumMinSd](docs/RelHumMinSd.md)
 - [RelHumSd](docs/RelHumSd.md)
 - [SamplePoints](docs/SamplePoints.md)
 - [SamplePointsInner](docs/SamplePointsInner.md)
 - [SfcPres](docs/SfcPres.md)
 - [SfcPresAvg](docs/SfcPresAvg.md)
 - [SfcPresAvgSd](docs/SfcPresAvgSd.md)
 - [SfcPresMax](docs/SfcPresMax.md)
 - [SfcPresMaxSd](docs/SfcPresMaxSd.md)
 - [SfcPresMin](docs/SfcPresMin.md)
 - [SfcPresMinSd](docs/SfcPresMinSd.md)
 - [SfcPresSd](docs/SfcPresSd.md)
 - [SnowDepth](docs/SnowDepth.md)
 - [SnowDepthSd](docs/SnowDepthSd.md)
 - [Snowfall](docs/Snowfall.md)
 - [SnowfallFreq](docs/SnowfallFreq.md)
 - [SnowfallFreq0](docs/SnowfallFreq0.md)
 - [SnowfallFreq001To009](docs/SnowfallFreq001To009.md)
 - [SnowfallFreq010To024](docs/SnowfallFreq010To024.md)
 - [SnowfallFreq025To049](docs/SnowfallFreq025To049.md)
 - [SnowfallFreq050To099](docs/SnowfallFreq050To099.md)
 - [SnowfallFreq100To149](docs/SnowfallFreq100To149.md)
 - [SnowfallFreq150To249](docs/SnowfallFreq150To249.md)
 - [SnowfallFreq250Plus](docs/SnowfallFreq250Plus.md)
 - [SnowfallSd](docs/SnowfallSd.md)
 - [SpcHum](docs/SpcHum.md)
 - [SpcHumAvg](docs/SpcHumAvg.md)
 - [SpcHumAvgSd](docs/SpcHumAvgSd.md)
 - [SpcHumMax](docs/SpcHumMax.md)
 - [SpcHumMaxSd](docs/SpcHumMaxSd.md)
 - [SpcHumMin](docs/SpcHumMin.md)
 - [SpcHumMinSd](docs/SpcHumMinSd.md)
 - [SpcHumSd](docs/SpcHumSd.md)
 - [SubdivCode](docs/SubdivCode.md)
 - [SubdivName](docs/SubdivName.md)
 - [Temp](docs/Temp.md)
 - [TempAvg](docs/TempAvg.md)
 - [TempAvgSd](docs/TempAvgSd.md)
 - [TempMax](docs/TempMax.md)
 - [TempMaxSd](docs/TempMaxSd.md)
 - [TempMin](docs/TempMin.md)
 - [TempMinSd](docs/TempMinSd.md)
 - [TempSd](docs/TempSd.md)
 - [Timestamp](docs/Timestamp.md)
 - [TimestampEnd](docs/TimestampEnd.md)
 - [TimestampRangeObj](docs/TimestampRangeObj.md)
 - [TimestampStart](docs/TimestampStart.md)
 - [Timezone](docs/Timezone.md)
 - [WetBulb](docs/WetBulb.md)
 - [WetBulbAvg](docs/WetBulbAvg.md)
 - [WetBulbAvgSd](docs/WetBulbAvgSd.md)
 - [WetBulbMax](docs/WetBulbMax.md)
 - [WetBulbMaxSd](docs/WetBulbMaxSd.md)
 - [WetBulbMin](docs/WetBulbMin.md)
 - [WetBulbMinSd](docs/WetBulbMinSd.md)
 - [WetBulbSd](docs/WetBulbSd.md)
 - [WindDir](docs/WindDir.md)
 - [WindDir100m](docs/WindDir100m.md)
 - [WindDir100mAvg](docs/WindDir100mAvg.md)
 - [WindDir80m](docs/WindDir80m.md)
 - [WindDir80mAvg](docs/WindDir80mAvg.md)
 - [WindDirAvg](docs/WindDirAvg.md)
 - [WindSpd](docs/WindSpd.md)
 - [WindSpdAvg](docs/WindSpdAvg.md)
 - [WindSpdAvgSd](docs/WindSpdAvgSd.md)
 - [WindSpdMax](docs/WindSpdMax.md)
 - [WindSpdMaxSd](docs/WindSpdMaxSd.md)
 - [WindSpdMin](docs/WindSpdMin.md)
 - [WindSpdMinSd](docs/WindSpdMinSd.md)
 - [WindSpdSd](docs/WindSpdSd.md)
 - [WindVecSpd](docs/WindVecSpd.md)
 - [WindVecSpd100m](docs/WindVecSpd100m.md)
 - [WindVecSpd80m](docs/WindVecSpd80m.md)

## Documentation For Authorization


## ApiKeyAuth

- **Type**: API key
- **API key parameter name**: X-API-KEY
- **Location**: HTTP header


## Author

support@weathersource.com
