# swagger_client.DmasApi

All URIs are relative to *https://climatology.weathersourceapis.com/v2*

Method | HTTP request | Description
------------- | ------------- | -------------
[**dmas_dma_id_days_date_get**](DmasApi.md#dmas_dma_id_days_date_get) | **GET** /dmas/{dmaId}/days/{date} | A day of weather climatology for a DMA.
[**dmas_dma_id_days_date_startdate_end_get**](DmasApi.md#dmas_dma_id_days_date_startdate_end_get) | **GET** /dmas/{dmaId}/days/{dateStart},{dateEnd} | A contiguous range of daily weather climatology for a DMA.
[**dmas_dma_id_hours_timestamp_get**](DmasApi.md#dmas_dma_id_hours_timestamp_get) | **GET** /dmas/{dmaId}/hours/{timestamp} | An hour of weather climatology for a DMA
[**dmas_dma_id_hours_timestamp_starttimestamp_end_get**](DmasApi.md#dmas_dma_id_hours_timestamp_starttimestamp_end_get) | **GET** /dmas/{dmaId}/hours/{timestampStart},{timestampEnd} | A contiguous range of hourly weather climatology for a DMA.

# **dmas_dma_id_days_date_get**
> ClimatologyDmaDayObj dmas_dma_id_days_date_get(dma_id, _date, fields, unit_scale=unit_scale)

A day of weather climatology for a DMA.

Returns a single day of climatological weather data for a Designated Market Area.

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: ApiKeyAuth
configuration = swagger_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.DmasApi(swagger_client.ApiClient(configuration))
dma_id = 56 # int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
_date = '2013-10-20' # date | An date formatted as a RFC3339 date value.
fields = ['fields_example'] # list[str] | A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
unit_scale = 'IMPERIAL' # str | The unit scale for returned values.<br> (optional) (default to IMPERIAL)

try:
    # A day of weather climatology for a DMA.
    api_response = api_instance.dmas_dma_id_days_date_get(dma_id, _date, fields, unit_scale=unit_scale)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DmasApi->dmas_dma_id_days_date_get: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **dma_id** | **int**| A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/). | 
 **_date** | **date**| An date formatted as a RFC3339 date value. | 
 **fields** | [**list[str]**](str.md)| A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)*  | 
 **unit_scale** | **str**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL]

### Return type

[**ClimatologyDmaDayObj**](ClimatologyDmaDayObj.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **dmas_dma_id_days_date_startdate_end_get**
> ClimatologyDmaDayObj dmas_dma_id_days_date_startdate_end_get(dma_id, date_start, date_end, fields, unit_scale=unit_scale)

A contiguous range of daily weather climatology for a DMA.

Returns a contiguous range of daily climatological weather data for a Designated Market Area.

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: ApiKeyAuth
configuration = swagger_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.DmasApi(swagger_client.ApiClient(configuration))
dma_id = 56 # int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
date_start = '2013-10-20' # date | An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
date_end = '2013-10-20' # date | An date formatted as a RFC3339 date value that must occur temporally after dateStart.
fields = ['fields_example'] # list[str] | A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
unit_scale = 'IMPERIAL' # str | The unit scale for returned values.<br> (optional) (default to IMPERIAL)

try:
    # A contiguous range of daily weather climatology for a DMA.
    api_response = api_instance.dmas_dma_id_days_date_startdate_end_get(dma_id, date_start, date_end, fields, unit_scale=unit_scale)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DmasApi->dmas_dma_id_days_date_startdate_end_get: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **dma_id** | **int**| A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/). | 
 **date_start** | **date**| An date formatted as a RFC3339 date value that must occur temporally before dateEnd. | 
 **date_end** | **date**| An date formatted as a RFC3339 date value that must occur temporally after dateStart. | 
 **fields** | [**list[str]**](str.md)| A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)*  | 
 **unit_scale** | **str**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL]

### Return type

[**ClimatologyDmaDayObj**](ClimatologyDmaDayObj.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **dmas_dma_id_hours_timestamp_get**
> ClimatologyDmaHourObj dmas_dma_id_hours_timestamp_get(dma_id, timestamp, fields, unit_scale=unit_scale)

An hour of weather climatology for a DMA

Returns a single hour of climatological weather data for a Designated Market Area.

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: ApiKeyAuth
configuration = swagger_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.DmasApi(swagger_client.ApiClient(configuration))
dma_id = 56 # int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
timestamp = '2013-10-20T19:20:30+01:00' # datetime | A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
fields = ['fields_example'] # list[str] | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
unit_scale = 'IMPERIAL' # str | The unit scale for returned values.<br> (optional) (default to IMPERIAL)

try:
    # An hour of weather climatology for a DMA
    api_response = api_instance.dmas_dma_id_hours_timestamp_get(dma_id, timestamp, fields, unit_scale=unit_scale)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DmasApi->dmas_dma_id_hours_timestamp_get: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **dma_id** | **int**| A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/). | 
 **timestamp** | **datetime**| A timestamp formatted as an RFC3339 date-time value. The UTC offset is required. | 
 **fields** | [**list[str]**](str.md)| A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)*  | 
 **unit_scale** | **str**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL]

### Return type

[**ClimatologyDmaHourObj**](ClimatologyDmaHourObj.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **dmas_dma_id_hours_timestamp_starttimestamp_end_get**
> ClimatologyDmaHourObj dmas_dma_id_hours_timestamp_starttimestamp_end_get(dma_id, timestamp_start, timestamp_end, fields, unit_scale=unit_scale)

A contiguous range of hourly weather climatology for a DMA.

Returns a contiguous range of hourly climatological weather data for a Designated Market Area.

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: ApiKeyAuth
configuration = swagger_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.DmasApi(swagger_client.ApiClient(configuration))
dma_id = 56 # int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
timestamp_start = '2013-10-20T19:20:30+01:00' # datetime | A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
timestamp_end = '2013-10-20T19:20:30+01:00' # datetime | A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
fields = ['fields_example'] # list[str] | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
unit_scale = 'IMPERIAL' # str | The unit scale for returned values.<br> (optional) (default to IMPERIAL)

try:
    # A contiguous range of hourly weather climatology for a DMA.
    api_response = api_instance.dmas_dma_id_hours_timestamp_starttimestamp_end_get(dma_id, timestamp_start, timestamp_end, fields, unit_scale=unit_scale)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DmasApi->dmas_dma_id_hours_timestamp_starttimestamp_end_get: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **dma_id** | **int**| A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/). | 
 **timestamp_start** | **datetime**| A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required. | 
 **timestamp_end** | **datetime**| A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required. | 
 **fields** | [**list[str]**](str.md)| A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)*  | 
 **unit_scale** | **str**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL]

### Return type

[**ClimatologyDmaHourObj**](ClimatologyDmaHourObj.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

