# swagger_client.PointsApi

All URIs are relative to *https://climatology.weathersourceapis.com/v2*

Method | HTTP request | Description
------------- | ------------- | -------------
[**points_latitudelongitude_days_date_get**](PointsApi.md#points_latitudelongitude_days_date_get) | **GET** /points/{latitude},{longitude}/days/{date} | A day of weather climatology for a Latitude/Longitude point.
[**points_latitudelongitude_days_date_startdate_end_get**](PointsApi.md#points_latitudelongitude_days_date_startdate_end_get) | **GET** /points/{latitude},{longitude}/days/{dateStart},{dateEnd} | A contiguous range of daily weather climatology for a Latitude/Longitude point.
[**points_latitudelongitude_hours_timestamp_get**](PointsApi.md#points_latitudelongitude_hours_timestamp_get) | **GET** /points/{latitude},{longitude}/hours/{timestamp} | An hour of weather climatology for a Latitude/Longitude point.
[**points_latitudelongitude_hours_timestamp_starttimestamp_end_get**](PointsApi.md#points_latitudelongitude_hours_timestamp_starttimestamp_end_get) | **GET** /points/{latitude},{longitude}/hours/{timestampStart},{timestampEnd} | A contiguous range of hourly weather climatology for a Latitude/Longitude point.

# **points_latitudelongitude_days_date_get**
> ClimatologyPointDayObj points_latitudelongitude_days_date_get(latitude, longitude, _date, fields, unit_scale=unit_scale)

A day of weather climatology for a Latitude/Longitude point.

Returns a single day of climatological weather data for a Latitude/Longitude point.

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: ApiKeyAuth
configuration = swagger_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.PointsApi(swagger_client.ApiClient(configuration))
latitude = 3.4 # float | A latitude value between -90° and 90°.
longitude = 3.4 # float | A longitude value between -180° (West) and 180° (East).
_date = '2013-10-20' # date | An date formatted as a RFC3339 date value.
fields = ['fields_example'] # list[str] | A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
unit_scale = 'IMPERIAL' # str | The unit scale for returned values.<br> (optional) (default to IMPERIAL)

try:
    # A day of weather climatology for a Latitude/Longitude point.
    api_response = api_instance.points_latitudelongitude_days_date_get(latitude, longitude, _date, fields, unit_scale=unit_scale)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling PointsApi->points_latitudelongitude_days_date_get: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **latitude** | **float**| A latitude value between -90° and 90°. | 
 **longitude** | **float**| A longitude value between -180° (West) and 180° (East). | 
 **_date** | **date**| An date formatted as a RFC3339 date value. | 
 **fields** | [**list[str]**](str.md)| A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)*  | 
 **unit_scale** | **str**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL]

### Return type

[**ClimatologyPointDayObj**](ClimatologyPointDayObj.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **points_latitudelongitude_days_date_startdate_end_get**
> ClimatologyPointDayObj points_latitudelongitude_days_date_startdate_end_get(latitude, longitude, date_start, date_end, fields, unit_scale=unit_scale)

A contiguous range of daily weather climatology for a Latitude/Longitude point.

Returns a contiguous range of daily climatological weather data for a Latitude/Longitude point.

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: ApiKeyAuth
configuration = swagger_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.PointsApi(swagger_client.ApiClient(configuration))
latitude = 3.4 # float | A latitude value between -90° and 90°.
longitude = 3.4 # float | A longitude value between -180° (West) and 180° (East).
date_start = '2013-10-20' # date | An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
date_end = '2013-10-20' # date | An date formatted as a RFC3339 date value that must occur temporally after dateStart.
fields = ['fields_example'] # list[str] | A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
unit_scale = 'IMPERIAL' # str | The unit scale for returned values.<br> (optional) (default to IMPERIAL)

try:
    # A contiguous range of daily weather climatology for a Latitude/Longitude point.
    api_response = api_instance.points_latitudelongitude_days_date_startdate_end_get(latitude, longitude, date_start, date_end, fields, unit_scale=unit_scale)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling PointsApi->points_latitudelongitude_days_date_startdate_end_get: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **latitude** | **float**| A latitude value between -90° and 90°. | 
 **longitude** | **float**| A longitude value between -180° (West) and 180° (East). | 
 **date_start** | **date**| An date formatted as a RFC3339 date value that must occur temporally before dateEnd. | 
 **date_end** | **date**| An date formatted as a RFC3339 date value that must occur temporally after dateStart. | 
 **fields** | [**list[str]**](str.md)| A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)*  | 
 **unit_scale** | **str**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL]

### Return type

[**ClimatologyPointDayObj**](ClimatologyPointDayObj.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **points_latitudelongitude_hours_timestamp_get**
> ClimatologyPointHourObj points_latitudelongitude_hours_timestamp_get(latitude, longitude, timestamp, fields, unit_scale=unit_scale)

An hour of weather climatology for a Latitude/Longitude point.

Returns a single hour of climatological weather data for a Latitude/Longitude point.

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: ApiKeyAuth
configuration = swagger_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.PointsApi(swagger_client.ApiClient(configuration))
latitude = 3.4 # float | A latitude value between -90° and 90°.
longitude = 3.4 # float | A longitude value between -180° (West) and 180° (East).
timestamp = '2013-10-20T19:20:30+01:00' # datetime | A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
fields = ['fields_example'] # list[str] | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
unit_scale = 'IMPERIAL' # str | The unit scale for returned values.<br> (optional) (default to IMPERIAL)

try:
    # An hour of weather climatology for a Latitude/Longitude point.
    api_response = api_instance.points_latitudelongitude_hours_timestamp_get(latitude, longitude, timestamp, fields, unit_scale=unit_scale)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling PointsApi->points_latitudelongitude_hours_timestamp_get: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **latitude** | **float**| A latitude value between -90° and 90°. | 
 **longitude** | **float**| A longitude value between -180° (West) and 180° (East). | 
 **timestamp** | **datetime**| A timestamp formatted as an RFC3339 date-time value. The UTC offset is required. | 
 **fields** | [**list[str]**](str.md)| A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)*  | 
 **unit_scale** | **str**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL]

### Return type

[**ClimatologyPointHourObj**](ClimatologyPointHourObj.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **points_latitudelongitude_hours_timestamp_starttimestamp_end_get**
> ClimatologyPointHourObj points_latitudelongitude_hours_timestamp_starttimestamp_end_get(latitude, longitude, timestamp_start, timestamp_end, fields, unit_scale=unit_scale)

A contiguous range of hourly weather climatology for a Latitude/Longitude point.

Returns a contiguous range of hourly climatological weather data for a Latitude/Longitude point.

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: ApiKeyAuth
configuration = swagger_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.PointsApi(swagger_client.ApiClient(configuration))
latitude = 3.4 # float | A latitude value between -90° and 90°.
longitude = 3.4 # float | A longitude value between -180° (West) and 180° (East).
timestamp_start = '2013-10-20T19:20:30+01:00' # datetime | A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
timestamp_end = '2013-10-20T19:20:30+01:00' # datetime | A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
fields = ['fields_example'] # list[str] | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
unit_scale = 'IMPERIAL' # str | The unit scale for returned values.<br> (optional) (default to IMPERIAL)

try:
    # A contiguous range of hourly weather climatology for a Latitude/Longitude point.
    api_response = api_instance.points_latitudelongitude_hours_timestamp_starttimestamp_end_get(latitude, longitude, timestamp_start, timestamp_end, fields, unit_scale=unit_scale)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling PointsApi->points_latitudelongitude_hours_timestamp_starttimestamp_end_get: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **latitude** | **float**| A latitude value between -90° and 90°. | 
 **longitude** | **float**| A longitude value between -180° (West) and 180° (East). | 
 **timestamp_start** | **datetime**| A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required. | 
 **timestamp_end** | **datetime**| A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required. | 
 **fields** | [**list[str]**](str.md)| A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)*  | 
 **unit_scale** | **str**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL]

### Return type

[**ClimatologyPointHourObj**](ClimatologyPointHourObj.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

